// -*- mode: js; js-indent-level: 4; indent-tabs-mode: nil -*-

/* The name of this package (not localized) */
const PACKAGE_NAME = 'gnome-shell';
/* The version of this package */
const PACKAGE_VERSION = '3.9.1';
/* 1 if gnome-bluetooth is available, 0 otherwise */
const HAVE_BLUETOOTH = 1;
/* gettext package */
const GETTEXT_PACKAGE = 'gnome-shell';
/* locale dir */
const LOCALEDIR = '/home/florian/opt/gnome/share/locale';
/* other standard directories */
const LIBEXECDIR = '/home/florian/opt/gnome/libexec';
const SYSCONFDIR = '/home/florian/opt/gnome/etc';
